# Package for Building Python Extensions to TIBCO Spotfire® 

This package provides functions used for integrating Python with Spotfire, including: 
* reading and writing files in Spotfire Binary Data Format (SBDF)
* building Spotfire Packages (SPKs) for distributing Python interpreters and custom packages with Spotfire
* internal handler code for executing Data Functions from Spotfire

### Installation
```sh
pip install spotfire
```

### License
BSD-type 3-Clause License.  See the file ```LICENSE``` included in the package.